pub struct DeviceIteratorGetNextResponse {
pub devices: Vec<DeviceEvent>,
}Fields
devices: Vec<DeviceEvent>Trait Implementations
Sourceimpl Clone for DeviceIteratorGetNextResponse
impl Clone for DeviceIteratorGetNextResponse
Sourcefn clone(&self) -> DeviceIteratorGetNextResponse
fn clone(&self) -> DeviceIteratorGetNextResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<D: ResourceDialect> Decode<DeviceIteratorGetNextResponse, D> for DeviceIteratorGetNextResponse
impl<D: ResourceDialect> Decode<DeviceIteratorGetNextResponse, D> for DeviceIteratorGetNextResponse
Sourceimpl<D: ResourceDialect> Encode<DeviceIteratorGetNextResponse, D> for &DeviceIteratorGetNextResponse
impl<D: ResourceDialect> Encode<DeviceIteratorGetNextResponse, D> for &DeviceIteratorGetNextResponse
Sourceimpl<D: ResourceDialect, T0: Encode<UnboundedVector<DeviceEvent>, D>> Encode<DeviceIteratorGetNextResponse, D> for (T0,)
impl<D: ResourceDialect, T0: Encode<UnboundedVector<DeviceEvent>, D>> Encode<DeviceIteratorGetNextResponse, D> for (T0,)
impl Persistable for DeviceIteratorGetNextResponse
impl StructuralPartialEq for DeviceIteratorGetNextResponse
Sourceimpl TypeMarker for DeviceIteratorGetNextResponse
impl TypeMarker for DeviceIteratorGetNextResponse
Sourcetype Owned = DeviceIteratorGetNextResponse
type Owned = DeviceIteratorGetNextResponse
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DeviceIteratorGetNextResponse
impl ValueTypeMarker for DeviceIteratorGetNextResponse
Sourcetype Borrowed<'a> = &'a DeviceIteratorGetNextResponse
type Borrowed<'a> = &'a DeviceIteratorGetNextResponse
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for DeviceIteratorGetNextResponse
impl RefUnwindSafe for DeviceIteratorGetNextResponse
impl Send for DeviceIteratorGetNextResponse
impl Sync for DeviceIteratorGetNextResponse
impl Unpin for DeviceIteratorGetNextResponse
impl UnsafeUnpin for DeviceIteratorGetNextResponse
impl UnwindSafe for DeviceIteratorGetNextResponse